Module runtime

Module runtime 

Structs

CallStack
Represents a call stack and its associated locals.
RuntimeError
A runtime error raised by a Ranty program.
StackFrame
Represents a call stack frame.
UnwindState
VM
The Ranty Virtual Machine.

Enums

Intent
Actions that can be queued on a stack frame that are performed before the frame runs.
InvokePipeStepState
States for the InvokePipeStep intent.
LogicShortCircuitHandling
Defines short-circuiting behaviors for logic operators.
RuntimeErrorType
Provides general categories of runtime errors encountered in Ranty.
SetterKey
SetterValueSource
Describes where a setter gets its RHS value.
StackFrameFlavor
Hints at what kind of program element a specific stack frame represents.
VarWriteMode
Defines variable write modes for setter intents. Used by function definitions to control conditional definition behavior.

Constants

MAX_STACK_SIZE
The largest possible stack size before a stack overflow error is raised by the runtime.

Type Aliases

RuntimeResult
Type alias for Result<T, RuntimeError>