pub type ValueSliceSetResult = Result<(), SliceError>;Expand description
The result type used by Ranty value slice write operations.
Aliased Type
pub enum ValueSliceSetResult {
Ok(()),
Err(SliceError),
}pub type ValueSliceSetResult = Result<(), SliceError>;The result type used by Ranty value slice write operations.
pub enum ValueSliceSetResult {
Ok(()),
Err(SliceError),
}