Structs
- Call
Stack - Represents a call stack and its associated locals.
- Runtime
Error - A runtime error raised by a Ranty program.
- Stack
Frame - Represents a call stack frame.
- Unwind
State - VM
- The Ranty Virtual Machine.
Enums
- Intent
- Actions that can be queued on a stack frame that are performed before the frame runs.
- Invoke
Pipe Step State - States for the
InvokePipeStepintent. - Logic
Short Circuit Handling - Defines short-circuiting behaviors for logic operators.
- Runtime
Error Type - Provides general categories of runtime errors encountered in Ranty.
- Setter
Key - Setter
Value Source - Describes where a setter gets its RHS value.
- Stack
Frame Flavor - Hints at what kind of program element a specific stack frame represents.
- VarWrite
Mode - Defines variable write modes for setter intents. Used by function definitions to control conditional definition behavior.
Constants
- MAX_
STACK_ SIZE - The largest possible stack size before a stack overflow error is raised by the runtime.
Type Aliases
- Runtime
Result - Type alias for
Result<T, RuntimeError>